@@ -1,10 +1,12 @@
 package POE::Component::Server::SimpleSMTP::Constants;
+BEGIN {
+  $POE::Component::Server::SimpleSMTP::Constants::VERSION = '1.46';
+}
+
+#ABSTRACT: importable constants for POE::Component::Server::SimpleSMTP plugins.
 
 use strict;
 use warnings;
-use vars qw($VERSION);
-
-$VERSION = '0.01';
 
 require Exporter;
 our @ISA = qw( Exporter );
@@ -18,12 +20,19 @@ sub SMTPD_EAT_PLUGIN	() { 3 }
 sub SMTPD_EAT_ALL	() { 4 }
 
 1;
+
+
 __END__
+=pod
 
 =head1 NAME
 
 POE::Component::Server::SimpleSMTP::Constants - importable constants for POE::Component::Server::SimpleSMTP plugins.
 
+=head1 VERSION
+
+version 1.46
+
 =head1 SYNOPSIS
 
   use POE::Component::Server::SimpleSMTP::Constants qw(:ALL);
@@ -54,16 +63,20 @@ Value: 4
 
 =back
 
-=head1 MAINTAINER
-
-Chris 'BinGOs' Williams <chris@bingosnet.co.uk>
-
-=head1 LICENSE
-
-Copyright C<(c)> Chris Williams.
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<POE::Component::Server::SimpleSMTP>
+
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
